package cn.usr.www.usrapirefcode.Activities;


import android.text.InputType;
import android.view.View;
import android.view.WindowManager;
import android.widget.CompoundButton;
import android.widget.EditText;
import android.widget.Switch;
import android.widget.TextView;
import android.widget.Toast;


import com.usr.rkapi.MyManager;

import Utiles.UsrLog;
import cn.usr.www.usrapirefcode.Activities.baseClass.UsrBaseActivity;
import cn.usr.www.usrapirefcode.R;

public class UsrNetWorkAbout extends UsrBaseActivity implements View.OnClickListener{

    private final String TAG = "UsrNetWorkAbout";

    private final int NET_TYPE_ETH = 0;
    private final int NET_TYPE_WIFI = 1;
    private final int NET_TYPE_MOBILE = 2;
    private final int NET_TYPE_NONE = -100;

    private Switch sw_ethernet_status;
    private Switch sw_ethernet_mode;
    private TextView tv_mac;
    /*网卡信息显示组件*/
    private EditText et_ip;
    private EditText et_dns;
    private EditText et_mask;
    private EditText et_gateway;
    private TextView  tv_curnetwork_type;

    private MyManager myManager = MyManager.getInstance(this);


    @Override
    protected void usrSetContentView() {
        setContentView(R.layout.network_about_activity);
        getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_HIDDEN);

    }

    @Override
    protected void usrInitComponent() {
        /*绑定服务*/
        myManager.bindAIDLService(this);

        sw_ethernet_status = (Switch)findViewById(R.id.sw_ethernet_status);
        tv_mac = (TextView)findViewById(R.id.tv_mac);
        sw_ethernet_mode = (Switch)findViewById(R.id.sw_ethernet_mode);
        et_ip = (EditText)findViewById(R.id.et_ip);
        et_dns = (EditText)findViewById(R.id.et_dns);
        et_mask = (EditText)findViewById(R.id.et_mask);
        et_gateway = (EditText)findViewById(R.id.et_gateway);

       /* et_ip.setInputType(InputType.TYPE_NULL);
        et_dns.setInputType(InputType.TYPE_NULL);
        et_mask.setInputType(InputType.TYPE_NULL);
        et_gateway.setInputType(InputType.TYPE_NULL);*/

        tv_curnetwork_type = (TextView)findViewById(R.id.tv_curnetwork_type);
        /*监听器设置*/

        /*网卡模式改变监听事件*/
        sw_ethernet_mode.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton compoundButton, boolean b) {
                setEthernetMode(b);
            }
        });
        /*网卡开光监听事件*/
        sw_ethernet_status.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton compoundButton, boolean b) {
                UsrLog.LOGD(TAG, "设置网卡状态:b ="+b);
                myManager.ethEnabled(b);
            }
        });
        findViewById(R.id.bt_refresh_network_info).setOnClickListener(this);
    }

    @Override
    protected void usrInitShowDatas() {

    }

    private void refreshNetworkInfo(){

        ethernetStatusShow();
        ethernetMacShow();
        ethernetModeShow();
        ethernetNetInfoShow();
        curNetworkTypeShow();
    }
    private void ethernetStatusShow(){

        boolean ethStatus = myManager.getEthStatus();
        UsrLog.LOGD(TAG, "ethernetStatusShow: [ethStatus]:"+ethStatus);
        sw_ethernet_status.setChecked(ethStatus);

    }

    private void curNetworkTypeShow(){
        int networkType = myManager.getCurrentNetType();

        tv_curnetwork_type.setText(integerNetworkTypeConvertString(networkType));
    }


    private String integerNetworkTypeConvertString(int networkType){
        switch (networkType){
            case NET_TYPE_ETH:{
                return "以太网";
            }
            case NET_TYPE_WIFI:{
                return "WIFI";
            }
            case NET_TYPE_MOBILE:{
                return "移动网络";
            }
            default:{
                return "未知网络";
            }
        }
    }


    private void ethernetNetInfoShow(){
        /*IP*/
        String ip = getEthernetIP();
        String dhcpIp = myManager.getDhcpIpAddress();
        String staticIp = myManager.getStaticEthIPAddress();
        String mask = myManager.getNetMask();
        String gateway = myManager.getGateway();
        String ethDns1 = myManager.getEthDns1();
        String ethDns2 = myManager.getEthDns2();

        UsrLog.LOGD(TAG, "ethernetNetInfoShow:ip = "+ip);
        UsrLog.LOGD(TAG, "ethernetNetInfoShow:dhcpIp = "+dhcpIp);
        UsrLog.LOGD(TAG, "ethernetNetInfoShow:staticIp = "+staticIp);
        UsrLog.LOGD(TAG, "ethernetNetInfoShow:mask = "+mask);
        UsrLog.LOGD(TAG, "ethernetNetInfoShow:gateway = "+gateway);
        UsrLog.LOGD(TAG, "ethernetNetInfoShow:ethDns1 = "+ethDns1);
        UsrLog.LOGD(TAG, "ethernetNetInfoShow:ethDns2 = "+ethDns2);
        et_ip.setHint(ip);
        /*mask*/
        et_mask.setHint(mask);
        /*gateway*/
        et_gateway.setHint(gateway);
        /*dns*/
        et_dns.setHint(ethDns1);
    }


    private String  getEthernetIP(){
        String ethernetMode = myManager.getEthMode();
        if(ethernetMode.equals("DHCP")){
            return myManager.getDhcpIpAddress();
        }else{
            return myManager.getStaticEthIPAddress();
        }
    }
    /*网卡模式设置*/
    private void ethernetModeShow(){

        String ethernetMode = myManager.getEthMode();
        UsrLog.LOGD(TAG, "ethernetMode = "+ethernetMode);

        if(ethernetMode.equals("DHCP")){
            sw_ethernet_mode.setChecked(true);
        }else {
            sw_ethernet_mode.setChecked(false);
        }

    }
    /*mac 地址显示*/
    private void ethernetMacShow(){

        String MAC = myManager.getEthMacAddress();
        UsrLog.LOGD(TAG, "MAC = "+MAC);
        tv_mac.setText(MAC);

    }

    @Override
    public void onClick(View view) {

        switch (view.getId()){
            case R.id.bt_refresh_network_info:{
                refreshNetworkInfo();
                break;
            }
        }

    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        myManager.unBindAIDLService(this);
    }

    private void  setEthernetMode(boolean isDhcp){

        if(isDhcp){
            myManager.setDhcpIpAddress(this);
        }else {
            setEthernetStaticInfo();
        }
    }

    private void setEthernetStaticInfo(){

        CharSequence setIp = et_ip.getText();
        CharSequence setDns = et_dns.getText();
        CharSequence setMask = et_mask.getText();
        CharSequence setGW = et_gateway.getText();
        if(setIp == null||setDns ==null||setMask == null||setGW ==null){
            UsrLog.LOGE(TAG, "network info get error!!");
            Toast.makeText(this, "请填入正确的网络信息!!", Toast.LENGTH_LONG);
            return;
        }
        String IP = setIp.toString();
        String GW = setGW.toString();
        String MASK = setMask.toString();
        String DNS1 = setDns.toString();
        String DNS2 = setDns.toString();

        UsrLog.LOGD(TAG, "IP= "+IP
                +"GW= "+GW
                +"MASK= "+MASK
                +"DNS1= "+DNS1
                +"DNS2= "+DNS2);

        myManager.setStaticEthIPAddress(IP,MASK,GW,DNS1,DNS2);
    }
}
